<?php
/**
 * Set up the content width value based on the theme's design.
 *
 * @see donut_content_width()
 *
 * @since Donut 1.0
 * @package Donut
 */

/**
 * donut only works in WordPress 5.0.3 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '5.0.3', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

if ( ! function_exists( 'donut_setup' ) ) :
	/**
 * donut setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 *
 * @since Donut 1.0
 */
	function donut_setup() {

		if ( ! isset( $content_width ) ) {
			$content_width = 578;
		}

		// This theme styles the visual editor to resemble the theme style.
		add_editor_style( array( 'css/editor-style.css', donut_font_url() ) );

		// Add RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		// Enable support for Post Thumbnails, and declare two sizes.
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 672, 372, true );
		add_image_size( 'donut-slider', 400, 332, true ); 
		add_image_size( 'donut-full-width', 1038, 576, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', __( 'Top primary menu', 'donut' ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */

		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		/**
		 * Add support for core custom logo.
		 *
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 76,
				'width'       => 316,
				'flex-width'  => false,
				'flex-height' => false,
			)
		);

		// This theme allows users to set a custom background.
		add_theme_support(
			'custom-background',
			apply_filters(
				'donut_custom_background_args',
				array(
					'default-color' => 'f5f5f5',
				)
			)
		);

		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );
	}
endif; // donut_setup
add_action( 'after_setup_theme', 'donut_setup' );

/**
 * Adjust content_width value for image attachment template.
 *
 * @since Donut 1.0
 */
function donut_content_width() {
	if ( is_attachment() && wp_attachment_is_image() ) {
		$GLOBALS['content_width'] = 810;
	}
}
add_action( 'template_redirect', 'donut_content_width' );


/*Fallback Menu - Donut*/
function donut_fallback() {
	wp_nav_menu(
		array(
			'theme_location' => 'primary',
			'show_home'      => true,
			'container'      => 'ul',
			'menu_class'     => 'main-menu donut_visibility_desktop',
		)
	);
}
function donut_device_fall() {
	wp_nav_menu(
		array(
			'theme_location' => 'primary',
			'show_home'      => false,
			'container'      => 'ul',
			'menu_class'     => 'device-menu',
		)
	);
}

/**
 * Register three donut widget areas.
 *
 * @since Donut 1.0
 */
function donut_widgets_init() {

	register_sidebar(
		array(
			'name'          => __( 'Content Sidebar', 'donut' ),
			'id'            => 'sidebar-2',
			'description'   => __( 'Additional sidebar that appears on the right.', 'donut' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="entry-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'donut_widgets_init' );

/**
 * Register Lato Google font for donut.
 *
 * @since Donut 1.0
 *
 * @return string
 */
function donut_font_url() {
	$font_url = '';
	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Lato, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Lato font: on or off', 'donut' ) ) {
		$font_url = add_query_arg( 'family', urlencode( 'Lato:300,400,700,900,300italic,400italic,700italic' ), '//fonts.googleapis.com/css' );
	}

	return $font_url;
}

function donut_get_comments_excerpt( $comment_ID = 0, $num_words = 20 ) {
	$comment      = get_comment( $comment_ID );
	$comment_text = strip_tags( $comment->comment_content );
	$blah         = explode( ' ', $comment_text );
	if (count( $blah ) > $num_words ) {
		$k             = $num_words;
		$use_dotdotdot = 1;
	} else {
		$k             = count( $blah );
		$use_dotdotdot = 0;
	}
	$excerpt = '';
	for ( $i = 0; $i < $k; $i++ ) {
		$excerpt .= $blah[$i] . ' ';
	}
	$excerpt .= ( $use_dotdotdot ) ? '...' : '';
	return apply_filters( 'donut_get_comments_excerpt', $excerpt );
}

/**
 * Enqueue scripts and styles for the front end.
 *
 * @since Donut 1.0
 */
function donut_scripts() {
	// Add Lato font, used in the main stylesheet.
	wp_enqueue_style( 'donut-lato', donut_font_url(), array(), null );

	wp_enqueue_style( 'donut-style-main', get_template_directory_uri() . '/css/main.css' );
	wp_enqueue_style( 'donut-style-media', get_template_directory_uri() . '/css/media.css' );
	wp_enqueue_style( 'donut-style', 'http://fonts.googleapis.com/css?family=Archivo+Narrow%3A400%2C700%2C400italic%2C700italic&amp;ver=1411468593' );

	wp_enqueue_script( 'donut-main-js', get_template_directory_uri() . '/js/main.js', array( 'jquery' ) );

	// Load the Internet Explorer specific stylesheet.
	wp_style_add_data( 'donut-ie', 'conditional', 'lt IE 9' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	function donut_slider() {
		wp_enqueue_script( 'donut-plugins-js', get_template_directory_uri() . '/js/donutslider.js', array( 'jquery' ) );
	}

}
add_action( 'wp_enqueue_scripts', 'donut_scripts' );

if ( ! function_exists( 'donut_the_attached_image' ) ) :
	/**
 * Print the attached image with a link to the next attached image.
 *
 * @since Donut 1.0
 */
	function donut_the_attached_image() {
		$post = get_post();
		/**
	 * Filter the default donut attachment size.
	 *
	 * @since Donut 1.0
	 *
	 * @param array $dimensions {
	 *     An array of height and width dimensions.
	 *
	 *     @type int $height Height of the image in pixels. Default 810.
	 *     @type int $width  Width of the image in pixels. Default 810.
	 * }
	 */
		$attachment_size     = apply_filters( 'donut_attachment_size', array( 810, 810 ) );
		$next_attachment_url = wp_get_attachment_url();

		/*
		 * Grab the IDs of all the image attachments in a gallery so we can get the URL
		 * of the next adjacent image in a gallery, or the first image (if we're
		 * looking at the last image in a gallery), or, in a gallery of one, just the
		 * link to that image file.
		 */
		$attachment_ids = get_posts(
			array(
				'post_parent'    => $post->post_parent,
				'fields'         => 'ids',
				'numberposts'    => -1,
				'post_status'    => 'inherit',
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
				'order'          => 'ASC',
				'orderby'        => 'menu_order ID',
			)
		);

		// If there is more than 1 attachment in a gallery...
		if ( count( $attachment_ids ) > 1 ) {
			foreach ( $attachment_ids as $attachment_id ) {
				if ( $attachment_id == $post->ID ) {
					$next_id = current( $attachment_ids );
					break;
				}
			}

			// get the URL of the next image attachment...
			if ( $next_id ) {
				$next_attachment_url = get_attachment_link( $next_id );
			} else {
				// or get the URL of the first image attachment.
				$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
			}
		}

		printf(
			'<a href="%1$s" rel="attachment">%2$s</a>',
			esc_url( $next_attachment_url ),
			wp_get_attachment_image( $post->ID, $attachment_size )
		);
	}
endif;

if ( ! function_exists( 'donut_list_authors' ) ) :
	/**
 * Print a list of all site contributors who published at least one post.
 *
 * @since Donut 1.0
 */
	function donut_list_authors() {
		$contributor_ids = get_users(
			array(
				'fields'  => 'ID',
				'orderby' => 'post_count',
				'order'   => 'DESC',
				'who'     => 'authors',
			)
		);

		foreach ( $contributor_ids as $contributor_id ) :
				$post_count = count_user_posts( $contributor_id );

				// Move on if user has not published a post (yet).
			if ( ! $post_count ) {
					continue;
			}
			?>

	<div class="contributor">
		<div class="contributor-info">
			<div class="contributor-avatar"><?php echo get_avatar( $contributor_id, 132 ); ?></div>
			<div class="contributor-summary">
				<h2 class="contributor-name"><?php echo esc_html( get_the_author_meta( 'display_name', $contributor_id ) ); ?></h2>
				<p class="contributor-bio">
					<?php echo esc_html( get_the_author_meta( 'description', $contributor_id ) ); ?>
				</p>
				<a class="button contributor-posts-link" href="<?php echo esc_url( get_author_posts_url( $contributor_id ) ); ?>">
					<?php /* translators: %d: Article */ ?>
					<?php printf( _n( '%d Article', '%d Articles', $post_count, 'donut' ), $post_count ); ?>
				</a>
			</div><!-- .contributor-summary -->
		</div><!-- .contributor-info -->
	</div><!-- .contributor -->

			<?php
	endforeach;
	}
endif;

/**
 * Extend the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Presence of header image except in Multisite signup and activate pages.
 * 3. Index views.
 * 4. Full-width content layout.
 * 5. Presence of footer widgets.
 * 6. Single views.
 * 7. Featured content layout.
 *
 * @since Donut 1.0
 *
 * @param array $classes A list of existing body class values.
 * @return array The filtered body class list.
 */
function donut_body_classes( $classes ) {
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	if ( get_header_image() ) {
		$classes[] = 'header-image';
	} elseif ( ! in_array( $GLOBALS['pagenow'], array( 'wp-activate.php', 'wp-signup.php' ) ) ) {
		$classes[] = 'masthead-fixed';
	}

	if ( is_archive() || is_search() || is_home() ) {
		$classes[] = 'list-view';
	}

	if ( ( ! is_active_sidebar( 'sidebar-2' ) )
		|| is_page_template( 'page-templates/full-width.php' )
		|| is_page_template( 'page-templates/gallery.php' )
		|| is_attachment() ) {
		$classes[] = 'full-width';
	}

	if ( is_singular() && ! is_front_page() ) {
		$classes[] = 'singular';
	} elseif ( is_front_page() ) {
		$classes[] = 'grid';
	}
	//one-side-wide
	return $classes;
}
add_filter( 'body_class', 'donut_body_classes' );

/**
 * Extend the default WordPress post classes.
 *
 * Adds a post class to denote:
 * Non-password protected page with a post thumbnail.
 *
 * @since Donut 1.0
 *
 * @param array $classes A list of existing post class values.
 * @return array The filtered post class list.
 */
function donut_post_classes( $classes ) {
	if ( ! post_password_required() && ! is_attachment() && has_post_thumbnail() ) {
		$classes[] = 'has-post-thumbnail';
	}

	return $classes;
}
add_filter( 'post_class', 'donut_post_classes' );

// Implement Custom Header features.
require get_template_directory() . '/inc/custom-header.php';

// Custom template tags for this theme.
require get_template_directory() . '/inc/template-tags.php';

// Add Theme Customizer functionality.
require get_template_directory() . '/inc/customizer.php';


function get_the_donut_excerpt() {
	$excerpt = get_the_content();
	$excerpt = strip_shortcodes( $excerpt );
	$excerpt = strip_tags( $excerpt );
	$the_str = substr( $excerpt, 0, 69 );
	echo esc_html( $the_str );
	return $the_str;
}

/**
 * Fix skip link focus in IE11.
 *
 */
function donut_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'donut_skip_link_focus_fix' );
